@@ -1,5 +1,7 @@
 #!/usr/bin/env python
-
+import requests
+import json
+import sys
 import weather_in
 from weather_in import __version__, api_key
 
